pilas.actores.mapatiled.XmlNode

Package pilas :: Package actores :: Module mapatiled :: Class XmlNode |
[hide private]
[frames] | no frames]

# Class XmlNode

source code

Representa un nodo XML.

Instance Methods | [hide private]
__init__(self, domElement) Construstor del nodo desde un elemento dom. | source code
getData(self) Extrae datos desde un nodo del DOM. | source code
getAttributeValue(self, name) Returns the value of the attribute having the specified name. | source code
getChild(self, tag) Retorna el primer nodo hijo que contenga el tag especificado. | source code
getChildren(self, tag) Retorna una lista de todos los nodos hijos que tienen el tag especificado. | source code

Method Details | [hide private]

### __init__(self, domElement) (Constructor) | source code
Construstor del nodo desde un elemento dom. :param domElement: Elemento de DOM a convertir.